%define libname %mklibname sbuild 1.7.2
%define devname %mklibname -d sbuild

Name: schroot
Version: 1.7.2
Release: %mkrel 1
Summary: Execute commands in a chroot environment
Group: Development/Other
License: GPLv3+
URL: http://packages.debian.org/schroot
Source0: http://ftp.de.debian.org/debian/pool/main/s/schroot/%{name}_%{version}.orig.tar.xz
Patch0: schroot-pam.patch
Patch1: schroot-default-config-path.patch
BuildRequires: pam-devel
BuildRequires: boost-devel
BuildRequires: lockdev-devel
BuildRequires: gettext
BuildRequires: libuuid-devel
BuildRequires: liblvm2app-devel
BuildRequires: cppunit-devel
BuildRequires: btrfs-progs
BuildRequires: debootstrap
BuildRequires: fakeroot
BuildRequires: groff
BuildRequires: cmake
BuildRequires: doxygen
BuildRequires: gtest-devel
BuildRequires: po4a

Suggests: lvm2
Suggests: btrfs-progs

%description
schroot allows users to execute commands or interactive shells in
different chroots.  Any number of named chroots may be created, and
access permissions given to each, including root access for normal
users, on a per-user or per-group basis.  Additionally, schroot can
switch to a different user in the chroot, using PAM for
authentication and authorisation.  
All operations are logged for security.

Several different types of chroot are supported, including normal
directories in the filesystem, and also block devices.  Sessions,
persistent chroots created on the fly from files (tar with optional
compression and zip) and LVM snapshots are also supported.

schroot supports kernel personalities, allowing the programs run
inside the chroot to have a different personality.  For example,
running 32-bit chroots on 64-bit systems, or even running binaries
from alternative operating systems such as SVR4 or Xenix.

schroot also integrates with sbuild, to allow building packages with
all supported chroot types, including session-managed chroot types
such as LVM snapshots.

schroot shares most of its options with dchroot, but offers vastly
more functionality.

%package -n dchroot
Group: Development/Other
Summary: Older tool similar to schroot

%description -n dchroot
dchroot allows users to execute commands or interactive shells in different 
chroots. Users can move between chroots as necessary. Enhanced functionality 
is available in the next generation tool called schroot.

%package -n %libname
Group: Development/Other
Summary: sbuild library for schroot and dchroot


%description -n %libname
sbuild library for schroot and dchroot

%package -n %devname
Group: Development/Other
Summary: Develoment files for schroot and dchroot
Requires: %libname = %version
Provides: schroot-devel

%description -n %devname
Develoment files for schroot and dchroot


%prep
%setup -q
%patch0 -p0
%patch1 -p0

%build
export CXXFLAGS="%optflags -std=c++11"
%cmake  -DCMAKE_INSTALL_LOCALSTATEDIR=/var \
	-DCMAKE_INSTALL_SYSCONFDIR=/etc \
	-Dlvm-snapshot=ON \
	-Dbtrfs-snapshot=ON \
	-Ddchroot=ON \
	-Ddchroot-dsa=ON \
	-DBTRFS_EXECUTABLE=/usr/sbin/btrfs \
	-DLVCREATE_EXECUTABLE=/usr/sbin/lvcreate \
	-DLVREMOVE_EXECUTABLE=/usr/sbin/lvremove

%make

%install
pushd build
%makeinstall_std
mkdir -p %{buildroot}%{_localstatedir}/lib/schroot/session
mkdir -p %{buildroot}%{_sysconfdir}/schroot/chroot.d
/sbin/ldconfig -n %{buildroot}/%{_libdir}

sed -i 's/\${GIT_RELEASE_VERSION}/%{version}/' %{buildroot}%{_libdir}/pkgconfig/sbuild.pc

%find_lang %{name}

%files -f build/%{name}.lang
%doc COPYING AUTHORS ChangeLog HACKING NEWS README THANKS TODO
%{_bindir}/schroot
%dir %{_sysconfdir}/schroot
%dir %{_sysconfdir}/schroot/chroot.d
%config(noreplace) %{_sysconfdir}/schroot/schroot.conf
%config(noreplace) %{_sysconfdir}/pam.d/schroot
%dir %{_sysconfdir}/schroot/setup.d
%{_sysconfdir}/bash_completion.d/schroot
%{_sysconfdir}/schroot/default/copyfiles
%{_sysconfdir}/schroot/default/fstab
%{_sysconfdir}/schroot/default/nssdatabases
%{_sysconfdir}/schroot/desktop/copyfiles
%{_sysconfdir}/schroot/desktop/fstab
%{_sysconfdir}/schroot/desktop/nssdatabases
%{_sysconfdir}/schroot/minimal/copyfiles
%{_sysconfdir}/schroot/minimal/fstab
%{_sysconfdir}/schroot/minimal/nssdatabases
%{_sysconfdir}/schroot/buildd/copyfiles
%{_sysconfdir}/schroot/buildd/fstab
%{_sysconfdir}/schroot/buildd/nssdatabases
%{_sysconfdir}/schroot/sbuild/copyfiles
%{_sysconfdir}/schroot/sbuild/fstab
%{_sysconfdir}/schroot/sbuild/nssdatabases
%{_sysconfdir}/schroot/setup.d/00check
%{_sysconfdir}/schroot/setup.d/05btrfs
%{_sysconfdir}/schroot/setup.d/05file
%{_sysconfdir}/schroot/setup.d/05lvm
%{_sysconfdir}/schroot/setup.d/05union
%{_sysconfdir}/schroot/setup.d/10mount
%{_sysconfdir}/schroot/setup.d/15binfmt
%{_sysconfdir}/schroot/setup.d/15killprocs
%{_sysconfdir}/schroot/setup.d/20copyfiles
%{_sysconfdir}/schroot/setup.d/20nssdatabases
%{_sysconfdir}/schroot/setup.d/50chrootname
%{_sysconfdir}/schroot/setup.d/70services
%{_sysconfdir}/schroot/setup.d/99check
%dir %{_libexecdir}/schroot
%{_libexecdir}/schroot/listmounts
%{_libexecdir}/schroot/mount
%dir %{_localstatedir}/lib/schroot
%{_localstatedir}/lib/schroot/session
%{_localstatedir}/lib/schroot/mount
%{_datadir}/%{name}/setup/common-config
%{_datadir}/%{name}/setup/common-data
%{_datadir}/%{name}/setup/common-functions
%{_mandir}/man1/schroot.1.*
%{_mandir}/de/man1/schroot.1.*
%{_mandir}/fr/man1/schroot.1.*
%{_mandir}/man5/schroot*.5.*
%{_mandir}/man7/schroot*.7.*
%{_mandir}/de/man5/schroot*.5.*
%{_mandir}/de/man7/schroot*.7.*
%{_mandir}/fr/man5/schroot*.5.*
%{_mandir}/fr/man7/schroot*.7.*

%files -n dchroot
%{_bindir}/dchroot*
%{_mandir}/man1/dchroot*.1.*
%{_mandir}/de/man1/dchroot*.1.*
%{_mandir}/fr/man1/dchroot*.1.*

%files -n %libname
%{_libdir}/*.so.*

%files -n %devname
%dir %{_includedir}/sbuild
%{_includedir}/sbuild/*
%{_libdir}/libsbuild.so
%{_libdir}/pkgconfig/sbuild.pc



%changelog
* Mon Mar 10 2014 philippem <philippem> 1.7.2-1.mga4
+ Revision: 601863
- Update to 1.7.2, fix build (mga#12976) thanks to Oleg Bosis

* Sat Oct 19 2013 umeabot <umeabot> 1.7.0-2.mga4
+ Revision: 536217
- Mageia 4 Mass Rebuild

* Mon Sep 23 2013 fwang <fwang> 1.7.0-1.mga4
+ Revision: 483730
- update file list
- force c++11
- new version 1.7.0

* Mon Sep 23 2013 fwang <fwang> 1.6.5-2.mga4
+ Revision: 483723
- rebuild for new boost

* Sun Jul 21 2013 fwang <fwang> 1.6.5-1.mga4
+ Revision: 456763
- new version 1.6.5

* Mon Jul 08 2013 fwang <fwang> 1.6.3-7.mga4
+ Revision: 451212
- rebuild for new boost

* Fri May 31 2013 philippem <philippem> 1.6.3-6.mga4
+ Revision: 433885
- fix depend on a set of devel packages (#10166)

* Thu Apr 11 2013 ennael <ennael> 1.6.3-5.mga3
+ Revision: 409606
- rebuild for boost 1.53

* Mon Jan 14 2013 umeabot <umeabot> 1.6.3-4.mga3
+ Revision: 381806
- Mass Rebuild - https://wiki.mageia.org/en/Feature:Mageia3MassRebuild

* Thu Dec 20 2012 fwang <fwang> 1.6.3-3.mga3
+ Revision: 333014
- rebuild for new boost

* Thu Sep 20 2012 philippem <philippem> 1.6.3-2.mga3
+ Revision: 296375
- add libsbuild packages

* Sun Sep 16 2012 philippem <philippem> 1.6.3-1.mga3
+ Revision: 294557
- New version 1.6.3

* Tue Jul 31 2012 fwang <fwang> 1.4.25-3.mga3
+ Revision: 276823
- rebuild for new boost

* Wed May 30 2012 fwang <fwang> 1.4.25-2.mga3
+ Revision: 249719
- rebuild for new boost

* Mon Mar 05 2012 philippem <philippem> 1.4.25-1.mga2
+ Revision: 218518
- Update to 1.4.25.

* Mon Nov 28 2011 fwang <fwang> 1.4.23-2.mga2
+ Revision: 173542
- rebuild for new boost

* Tue Sep 27 2011 philippem <philippem> 1.4.23-1.mga2
+ Revision: 149327
- update to new upstream 1.4.23 version

  + fwang <fwang>
    - fix group

  + stormi <stormi>
    - update release to ensure higher version than in mageia 1

* Tue Jun 28 2011 ahmad <ahmad> 1.4.22-1.mga2
+ Revision: 115195
- Add a patch to fix build with boost
- Add a dchroot sub-package

  + fwang <fwang>
    - use configure2_5x
    - use configure2_5x
    - rebuild for new boost

  + philippem <philippem>
    - New upstream stable release 1.4.22
      + Don't use rbind when mounting filesystems in the chroot
      + Session metadata includes the original chroot name
      + Improved man pages

* Mon Apr 25 2011 philippem <philippem> 1.4.21-2.mga1
+ Revision: 90249
-add patch for stat -add buildrequires and suggests btrfs-progs

* Fri Apr 22 2011 philippem <philippem> 1.4.21-1.mga1
+ Revision: 89742
- imported package schroot

